@@ -55,11 +55,8 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class DecryptAndVerifyTestCase extends Crypt_GPG_TestCase
+class DecryptAndVerifyTest extends Crypt_GPG_TestCase
 {
-    // string
-    // {{{ testDecryptVerify()
-
     /**
      * @group string
      */
@@ -83,10 +80,10 @@ class DecryptAndVerifyTestCase extends Crypt_GPG_TestCase
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with first-keypair@example.com, signed with
         // first-keypair@example.com
@@ -121,9 +118,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyNoPassphrase()
-
     /**
      * @group string
      */
@@ -147,10 +141,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with no-passphrase@example.com, signed with
         // first-keypair@example.com
@@ -184,16 +178,13 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyKeyNotFoundException_decrypt()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testDecryptVerifyKeyNotFoundException_decrypt()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // was encrypted with missing-key@example.com, signed with
         // first-keypair@example.com
         // {{{ encrypted data
@@ -225,16 +216,13 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyKeyNotFoundException_verify()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testDecryptVerifyKeyNotFoundException_verify()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // was encrypted with first-keypair@example.com, signed with
         // missing-key@example.com
         // {{{ encrypted data
@@ -272,16 +260,13 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyKeyNotFoundException_both()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testDecryptVerifyKeyNotFoundException_both()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // was encrypted and signed with missing-key@example.com
         // {{{ encrypted data
         $encryptedData = <<<TEXT
@@ -312,9 +297,6 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyKeyNotFoundVerifyIgnoreErrors()
-
     /**
      * @group string
      */
@@ -323,10 +305,10 @@ TEXT;
         $signature = new Crypt_GPG_Signature();
         $signature->setKeyId('8E3D36B1EA5AC75E');
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // was encrypted with first-keypair@example.com, signed with
         // missing-key@example.com
@@ -369,44 +351,35 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyNoDataException_invalid()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testDecryptVerifyNoDataException_invalid()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $encryptedData = 'Invalid OpenPGP data.';
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyNoDataException_empty()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testDecryptVerifyNoDataException_empty()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $encryptedData = '';
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyBadPassphraseException_missing()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptVerifyBadPassphraseException_missing()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with first-keypair@example.com, signed with
         // first-keypair@example.com
         // {{{ encrypted data no passphrase
@@ -438,16 +411,13 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyBadPassphraseException_bad()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptVerifyBadPassphraseException_bad()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with first-keypair@example.com, signed with
         // first-keypair@example.com
         // {{{ encrypted data no passphrase
@@ -480,9 +450,6 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyDual()
-
     /**
      * @group string
      */
@@ -506,10 +473,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with both first-keypair@example.com and
         // second-keypair@example.com, signed with first-keypair@example.com
@@ -563,9 +530,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyDualOnePassphrase()
-
     /**
      * @group string
      */
@@ -589,10 +553,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with both first-keypair@example.com and
         // no-passhprase@example.com, signed with first-keypair@example.com
@@ -644,16 +608,13 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptAndVerifyDualNoPassphraseKeyMissing()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptAndVerifyDualNoPassphraseKeyMissing()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with both first-keypair@example.com and
         // second-keypair@example.com
         // {{{ dual encrypted data
@@ -701,9 +662,6 @@ TEXT;
         $this->gpg->decryptAndVerify($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyDualSignatories()
-
     /**
      * @group string
      */
@@ -744,10 +702,10 @@ TEXT;
         $signature2->setUserId($userId2);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature1, $signature2)
-        );
+            'signatures' => [$signature1, $signature2]
+        ];
 
         // encrypted with first-keypair@example.com and signed with
         // first-keypair@example.com and second-keypair@example.com
@@ -783,9 +741,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifySignedOnly()
-
     /**
      * @group string
      */
@@ -809,10 +764,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // signed with first-keypair@example.com
         // {{{ signed data
@@ -833,9 +788,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFirstSubKey()
-
     /**
      * @group string
      */
@@ -859,10 +811,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with first subkey (ELG-E) of multiple-subkeys@example.com,
         // signed with first-keypair@example.com
@@ -892,9 +844,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifySecondSubKey()
-
     /**
      * @group string
      */
@@ -918,10 +867,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // encrypted with second subkey (RSA) of multiple-subkeys@example.com,
         // signed with first-keypair@example.com
@@ -951,9 +900,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifySignedOnlyBadSignature()
-
     /**
      * @group string
      */
@@ -970,10 +916,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => "Hello, Bob! Goodbye, Alice!\n",
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         // {{{ clearsigned data
         $clearsignedData = <<<TEXT
@@ -993,12 +939,9 @@ TEXT;
         // }}}
 
         $results = $this->gpg->decryptAndVerify($clearsignedData);
-        $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
+        $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results, true);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFile()
-
     /**
      * @group file
      */
@@ -1023,10 +966,10 @@ TEXT;
         // }}}
 
         $expectedMd5Sum     = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults    = array(
+        $expectedResults    = [
             'data'       => null,
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename  = $this->getDataFilename('testDecryptVerifyFile.asc');
         $outputFilename = $this->getTempFilename('testDecryptVerifyFile.plain');
@@ -1044,9 +987,6 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileToString()
-
     /**
      * @group file
      */
@@ -1070,11 +1010,10 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedSignatures = array($signature);
-        $expectedResults    = array(
+        $expectedResults = [
             'data'       => 'Hello, Alice! Goodbye, Bob!',
-            'signatures' => $expectedSignatures
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename  = $this->getDataFilename(
             'testDecryptVerifyFileToString.asc'
@@ -1087,9 +1026,6 @@ TEXT;
         $this->assertDecryptAndVerifyResultsEquals($expectedResults, $results);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileNoPassphrase()
-
     /**
      * @group file
      */
@@ -1113,11 +1049,11 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedMd5Sum     = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults    = array(
+        $expectedMd5Sum  = 'f96267d87551ee09bfcac16921e351c1';
+        $expectedResults = [
             'data'       => null,
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename  = $this->getDataFilename(
             'testDecryptVerifyFileNoPassphrase.asc'
@@ -1138,16 +1074,13 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileFileException_input()
-
     /**
-     * @expectedException Crypt_GPG_FileException
-     *
      * @group file
      */
     public function testDecryptVerifyFileFileException_input()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file does not exist
         $inputFilename = $this->getDataFilename(
             'testDecryptVerifyFileFileException_input.asc'
@@ -1156,16 +1089,13 @@ TEXT;
         $this->gpg->decryptAndVerifyFile($inputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileFileException_output()
-
     /**
-     * @expectedException Crypt_GPG_FileException
-     *
      * @group file
      */
     public function testDecryptVerifyFileFileException_output()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file is encrypted with first-keypair@example.com
         // output file does not exist
         $inputFilename  = $this->getDataFilename('testDecryptVerifyFile.asc');
@@ -1176,16 +1106,13 @@ TEXT;
         $this->gpg->decryptAndVerifyFile($inputFilename, $outputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileKeyNotFoundException_decrypt()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group file
      */
     public function testDecryptVerifyFileKeyNotFoundException_decrypt()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // file is encrypted with missing-key@example.com, not signed
         $inputFilename = $this->getDataFilename(
             'testDecryptFileKeyNotFoundException.asc'
@@ -1198,9 +1125,6 @@ TEXT;
         $this->gpg->decryptAndVerifyFile($inputFilename, $outputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileDual()
-
     /**
      * @group file
      */
@@ -1224,11 +1148,11 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedMd5Sum     = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults    = array(
+        $expectedMd5Sum  = 'f96267d87551ee09bfcac16921e351c1';
+        $expectedResults = [
             'data'       => null,
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename  = $this->getDataFilename(
             'testDecryptVerifyFileDual.asc'
@@ -1260,9 +1184,6 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileDualSignatories()
-
     /**
      * @group file
      */
@@ -1304,10 +1225,10 @@ TEXT;
         // }}}
 
         $expectedMd5Sum  = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults = array(
+        $expectedResults = [
             'data'       => null,
-            'signatures' => array($signature1, $signature2)
-        );
+            'signatures' => [$signature1, $signature2]
+        ];
 
         $inputFilename  = $this->getDataFilename(
             'testDecryptVerifyFileDualSignatories.asc'
@@ -1326,9 +1247,6 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileDualOnePassphrase()
-
     /**
      * @group file
      */
@@ -1352,11 +1270,11 @@ TEXT;
         $signature->setUserId($userId);
         // }}}
 
-        $expectedMd5Sum     = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults    = array(
+        $expectedMd5Sum  = 'f96267d87551ee09bfcac16921e351c1';
+        $expectedResults = [
             'data'       => null,
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename  = $this->getDataFilename(
             'testDecryptVerifyFileDualOnePassphrase.asc'
@@ -1387,23 +1305,17 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileNoDataException()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group file
      */
     public function testDecryptVerifyFileNoDataException()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $filename = $this->getDataFilename('testFileEmpty.plain');
         $this->gpg->decryptAndVerifyFile($filename);
     }
 
-    // }}}
-    // {{{ testDecryptVerifyFileSignedOnly()
-
     /**
      * @group file
      */
@@ -1428,10 +1340,10 @@ TEXT;
         // }}}
 
         $expectedMd5Sum = 'f96267d87551ee09bfcac16921e351c1';
-        $expectedResults    = array(
+        $expectedResults = [
             'data'       => null,
-            'signatures' => array($signature)
-        );
+            'signatures' => [$signature]
+        ];
 
         $inputFilename = $this->getDataFilename(
             'testVerifyFileNormalSignedData.asc'
@@ -1451,8 +1363,4 @@ TEXT;
         $md5Sum = $this->getMd5Sum($outputFilename);
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
-
-    // }}}
 }
-
-?>
