@@ -55,7 +55,7 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class EncryptTestCase extends Crypt_GPG_TestCase
+class EncryptTest extends Crypt_GPG_TestCase
 {
     public function testHasEncryptKeys()
     {
@@ -64,8 +64,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertTrue($this->gpg->hasEncryptKeys());
     }
 
-    // {{{ testEncrypt()
-
     /**
      * @group string
      */
@@ -84,9 +82,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($data, $decryptedData);
     }
 
-    // }}}
-    // {{{ testEncryptDual()
-
     /**
      * @group string
      */
@@ -111,38 +106,29 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($data, $decryptedData);
     }
 
-    // }}}
-    // {{{ testEncryptKeyNotFoundException_invalid()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testEncryptNotFoundException_invalid()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         $data = 'Hello, Alice! Goodbye, Bob!';
         $this->gpg->addEncryptKey('non-existent-key@example.com');
         $this->gpg->encrypt($data);
     }
 
-    // }}}
-    // {{{ testEncryptKeyNotFoundException_none()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testEncryptNotFoundException_none()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         $data = 'Hello, Alice! Goodbye, Bob!';
         $this->gpg->encrypt($data);
     }
 
-    // }}}
-    // {{{ testEncryptEmpty()
-
     /**
      * @group string
      */
@@ -159,11 +145,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($data, $decryptedData);
     }
 
-    // }}}
-
-    // file
-    // {{{ testEncryptFile()
-
     /**
      * @group file
      */
@@ -184,9 +165,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testEncryptFileDual()
-
     /**
      * @group file
      */
@@ -216,9 +194,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testEncryptFileToString()
-
     /**
      * @group file
      */
@@ -236,16 +211,13 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testEncryptFileFileException_input()
-
     /**
      * @group file
-     *
-     * @expectedException Crypt_GPG_FileException
      */
     public function testEncryptFileFileException_input()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file does not exist
         $filename =
             $this->getDataFilename('testEncryptFileFileException_input.plain');
@@ -254,16 +226,13 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->gpg->encryptFile($filename);
     }
 
-    // }}}
-    // {{{ testEncryptFileFileException_output()
-
     /**
      * @group file
-     *
-     * @expectedException Crypt_GPG_FileException
      */
     public function testEncryptFileFileException_output()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // output file does not exist
         $inputFilename  = $this->getDataFilename('testFileMedium.plain');
         $outputFilename = './non-existent' .
@@ -273,9 +242,6 @@ class EncryptTestCase extends Crypt_GPG_TestCase
         $this->gpg->encryptFile($inputFilename, $outputFilename);
     }
 
-    // }}}
-    // {{{ testEncryptFileEmpty()
-
     /**
      * @group file
      */
@@ -291,8 +257,4 @@ class EncryptTestCase extends Crypt_GPG_TestCase
 
         $this->assertEquals('', $decryptedData);
     }
-
-    // }}}
 }
-
-?>
