@@ -55,12 +55,9 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class ImportKeyTestCase extends Crypt_GPG_TestCase
+class ImportKeyTest extends Crypt_GPG_TestCase
 {
-    // set up
-    // {{{ setUp()
-
-    public function setUp()
+    public function setUp(): void
     {
         parent::setUp();
 
@@ -70,9 +67,6 @@ class ImportKeyTestCase extends Crypt_GPG_TestCase
         $this->gpg->getKeys();
     }
 
-    // }}}
-    // {{{ testImportKey_private()
-
     /**
      * @group string
      */
@@ -81,14 +75,14 @@ class ImportKeyTestCase extends Crypt_GPG_TestCase
         // Note: Some of GnuPG 2.1.x versions return different private_imported
         // and private_uchanged values, bug? GnuPG 2.1.15 returns 1 as expected.
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 1,
             'private_unchanged' => 0
-        );
+        ];
 
         // {{{ private key data
         $privateKeyData = <<<TEXT
@@ -134,22 +128,19 @@ TEXT;
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKey_public()
-
     /**
      * @group string
      */
     public function testImportKey_public()
     {
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 1,
             'public_unchanged'  => 0,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         // {{{ public key data
         $publicKeyData = <<<TEXT
@@ -192,9 +183,6 @@ TEXT;
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyAlreadyImported_private()
-
     /**
      * @group string
      */
@@ -242,34 +230,31 @@ TEXT;
 
         $result = $this->gpg->importKey($privateKeyData);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 1,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
 
         $result = $this->gpg->importKey($privateKeyData);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => version_compare($this->gpg->getVersion(), '2.1.0', 'ge') ? 1 : 0,
             'private_imported'  => 0,
             'private_unchanged'  => 1,
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyAlreadyImported_public()
-
     /**
      * @group string
      */
@@ -314,75 +299,66 @@ TEXT;
 
         $result = $this->gpg->importKey($publicKeyData);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 1,
             'public_unchanged'  => 0,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
 
         $result = $this->gpg->importKey($publicKeyData);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyNoDataException_invalid()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testImportKeyNoDataException_invalid()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $keyData = 'Invalid OpenPGP data.';
         $this->gpg->importKey($keyData);
     }
 
-    // }}}
-    // {{{ testImportKeyNoDataException_empty()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testImportKeyNoDataException_empty()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $keyData = '';
         $this->gpg->importKey($keyData);
     }
 
-    // }}}
-    // {{{ testImportKeyFile_private()
-
     /**
      * @group file
      */
     public function testImportKeyFile_private()
     {
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 1,
             'private_unchanged' => 0
-        );
+        ];
 
         $filename = $this->getDataFilename('testImportKeyFile_private.asc');
         $result   = $this->gpg->importKeyFile($filename);
@@ -390,22 +366,19 @@ TEXT;
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyFile_public()
-
     /**
      * @group file
      */
     public function testImportKeyFile_public()
     {
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 1,
             'public_unchanged'  => 0,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         $filename = $this->getDataFilename('testImportKeyFile_public.asc');
         $result   = $this->gpg->importKeyFile($filename);
@@ -413,9 +386,6 @@ TEXT;
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyFileAlreadyImported_private()
-
     /**
      * @group file
      */
@@ -424,34 +394,31 @@ TEXT;
         $filename = $this->getDataFilename('testImportKeyFile_private.asc');
         $result   = $this->gpg->importKeyFile($filename);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 1,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
 
         $result = $this->gpg->importKeyFile($filename);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
-            'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
+            'fingerprints'      => ['F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'],
             'public_imported'   => 0,
             'public_unchanged'  => version_compare($this->gpg->getVersion(), '2.1.0', 'ge') ? 1 : 0,
             'private_imported'  => 0,
             'private_unchanged'  => 1,
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyFileAlreadyImported_public()
-
     /**
      * @group file
      */
@@ -460,41 +427,38 @@ TEXT;
         $filename = $this->getDataFilename('testImportKeyFile_public.asc');
         $result = $this->gpg->importKeyFile($filename);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 1,
             'public_unchanged'  => 0,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
 
         $result = $this->gpg->importKeyFile($filename);
 
-        $expectedResult = array(
+        $expectedResult = [
             'fingerprint'       => '948F9835FF09F5F91CFF2AC1268AB7103435E65D',
-            'fingerprints'      => array('948F9835FF09F5F91CFF2AC1268AB7103435E65D'),
+            'fingerprints'      => ['948F9835FF09F5F91CFF2AC1268AB7103435E65D'],
             'public_imported'   => 0,
             'public_unchanged'  => 1,
             'private_imported'  => 0,
             'private_unchanged' => 0
-        );
+        ];
 
         $this->assertEquals($expectedResult, $result);
     }
 
-    // }}}
-    // {{{ testImportKeyFileFileException()
-
     /**
-     * @expectedException Crypt_GPG_FileException
-     *
      * @group file
      */
     public function testImportKeyFileFileException()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file does not exist
         $filename =
             $this->getDataFilename('testImportKeyFileFileException.asc');
@@ -502,21 +466,14 @@ TEXT;
         $this->gpg->importKeyFile($filename);
     }
 
-    // }}}
-    // {{{ testImportKeyFileNoDataException()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group file
      */
     public function testImportKeyFileNoDataException()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $filename = $this->getDataFilename('testFileEmpty.plain');
         $this->gpg->importKeyFile($filename);
     }
-
-    // }}}
 }
-
-?>
